@@ -2,7 +2,7 @@
 
 #
 # DaVinci Resolve 16.0 Debian package creator
-# Release 2019-09-10
+# Release 2019-09-27
 # By Daniel Tufvesson
 #
 
@@ -58,7 +58,7 @@ make_executable() {
 
 # Setup variables
 RESOLVE_VERSION=16.0
-DEB_STEPPING=2
+DEB_STEPPING=3
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -179,6 +179,8 @@ chmod -R a+rw /opt/resolve/easyDCP
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
+test ! -e /usr/lib64 && ln -s /usr/lib/x86_64-linux-gnu/ /usr/lib64
+exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
 check_command fakeroot
